This will mainly provide a means to dispatch to a special subset method which should stream the necessary data from disk. Users typically do not have to deal with this distinction directly and can rely on the AlignmentsTrack constructor to make the right choice.