This will mainly provide a means to dispatch to a special subseq method which should stream the necessary data from disk. Users typically do not have to deal with this distinction directly and can rely on the SequenceTrack constructor to make the right choice.

# S4 method for class 'ReferenceSequenceTrack'
initialize(.Object, stream, reference, ...)

Functions