The BSgenome-based version of the SequenceTrack class

# S4 method for class 'SequenceBSgenomeTrack'
initialize(.Object, sequence = NULL, ...)

Arguments

.Object

The object skeleton passed on by new() during class instantiation, to be filled in by the initialize method.

sequence

A BSgenome object with the full genomic sequence, or NULL.

...

Additional arguments.

Functions

  • initialize(SequenceBSgenomeTrack): Initialize the sequence and pointerCache slots before deferring to the SequenceTrack initializer for the remaining slots.

Slots

sequence

A BSgenome object (or NULL), realized on demand as individual chromosome sequences are accessed.

pointerCache

An environment holding pointers to the BSgenome sequences that have already been realized, to prevent garbage collection.