DNAStringSet-based version of the SequenceTrack classR/SequenceTrack-class.R
SequenceDNAStringSetTrack-class.RdThe DNAStringSet-based version of the SequenceTrack class
# S4 method for class 'SequenceDNAStringSetTrack'
initialize(.Object, sequence, ...)The object skeleton passed on by new() during class
instantiation, to be filled in by the initialize method.
A DNAStringSet object
with one DNA sequence per chromosome. The names have to match the chromosome
identifiers.
Additional arguments.
An initialized object of class
SequenceDNAStringSetTrack.
initialize(SequenceDNAStringSetTrack): Initialize the sequence slot
(defaulting to an empty DNAStringSet if
none is supplied) before deferring to the SequenceTrack initializer for the
remaining slots.
sequenceA DNAStringSet object
containing the sequence data, with one element per chromosome.