Some sample data sets used for the illustrative examples and the vignette.

Format

A heterogeneous collection of pre-built objects, one per data set, used to avoid recomputing or re-downloading data in examples and the vignette. Depending on the data set, the object is either a ready-to-plot Gviz track (e.g. AnnotationTrack, GeneRegionTrack, GenomeAxisTrack, IdeogramTrack, DataTrack or BiomartGeneRegionTrack), a GRanges or data.frame of annotation data, or a numeric scalar (from, to) marking a genomic start or end coordinate.