HTML image map information for annotation tracks.
coords(ImageMap, ...)
# S4 method for class 'NULL'
coords(ImageMap)
# S4 method for class 'ImageMap'
coords(ImageMap)
tags(ImageMap, ...)
# S4 method for class 'NULL'
tags(ImageMap)
# S4 method for class 'ImageMap'
tags(ImageMap)
# S4 method for class 'ImageMap'
show(object)Returns the coordinates from the image map.
Returns the tags from the image map.
Objects of the ImageMap-class are usually not created by the user,
hence the constructor function ImageMap is not exported in the name space.
coords(): Generics for coords.
coords(`NULL`): Returns the coordinates from the image map.
coords(ImageMap): Returns the coordinates from the image map.
tags(): Generics for tags.
tags(`NULL`): Returns the tags from the image map
tags(ImageMap): Returns the tags from the image map
show(ImageMap): Show method
coordsObject of class matrix, the image map coordinates, in the
order bottom-left x, bottom-left y, top-right x, top-right y. Row names are
mandatory for the matrix and have to be unique.
tagsObject of class list, the individual HTML tags for the image
map. The value of each list item has to be a named character vector, where
the names must match back into the row names of the coords matrix.
## ImageMap objects are usually not created directly by the user, but
## are populated as a side effect of plotting a GdObject. plotTracks()
## returns the plotted tracks (with their ImageMap populated) invisibly,
## and the coords() and tags() accessors can be used to query them.
at <- AnnotationTrack(
start = c(100, 300), width = 50,
chromosome = "chr1", genome = "hg19", name = "features"
)
res <- plotTracks(at)
coords(res[["features"]])
#> x1 y1 x2 y2
#> unknown 39.17073 64.5 124.8853 415.5
#> unknown.1 382.02899 64.5 467.7436 415.5
tags(res[["features"]])
#> $fill
#> unknown unknown.1
#> "lightblue" "lightblue"
#>
#> $strand
#> unknown unknown.1
#> "*" "*"
#>
#> $text
#> unknown unknown.1
#> "unknown" "unknown.1"
#>
#> $start
#> unknown unknown.1
#> "100" "300"
#>
#> $end
#> unknown unknown.1
#> "150" "350"
#>
#> $feature
#> unknown unknown.1
#> "unknown" "unknown"
#>
#> $group
#> unknown unknown.1
#> "1" "2"
#>
#> $id
#> unknown unknown.1
#> "unknown" "unknown.1"
#>
#> $density
#> unknown unknown.1
#> "1" "1"
#>
#> $exonId
#> unknown unknown.1
#> "unknown" "unknown.1"
#>
#> $origExonId
#> unknown unknown.1
#> "unknown" "unknown.1"
#>
#> $col
#> unknown unknown.1
#> "darkgray" "darkgray"
#>
#> $title
#> [1] "1" "2"
#>