BSgenome-based version of the SequenceTrack classR/SequenceTrack-class.R
SequenceBSgenomeTrack-class.RdThe BSgenome-based version of the SequenceTrack class
# S4 method for class 'SequenceBSgenomeTrack'
initialize(.Object, sequence = NULL, ...)The object skeleton passed on by new() during class
instantiation, to be filled in by the initialize method.
A BSgenome object with the full genomic sequence, or
NULL.
Additional arguments.
initialize(SequenceBSgenomeTrack): Initialize the sequence and
pointerCache slots before deferring to the SequenceTrack initializer
for the remaining slots.
sequenceA BSgenome object (or NULL), realized on demand as
individual chromosome sequences are accessed.
pointerCacheAn environment holding pointers to the BSgenome
sequences that have already been realized, to prevent garbage collection.